@@ -59,8 +59,10 @@ class AddWidgetWizard(hildon.WizardDialog):
         self.urlEntry = hildon.Entry(gtk.HILDON_SIZE_AUTO)
         self.urlEntry.set_placeholder("Enter a URL")
         self.urlEntry.set_text(urlIn)
+        self.urlEntry.select_region(0,-1)
+        
         vbox = gtk.VBox(False,10)
-        label = gtk.Label("Enter Feed Name:")
+        label = gtk.Label("Enter Feed URL:")
         vbox.pack_start(label)
         vbox.pack_start(self.urlEntry)
         self.notebook.append_page(vbox, None)
